"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const moment = require("moment");
async function _updateCache(cachePath, cache) {
    await fs.ensureFile(cachePath);
    await fs.writeJSON(cachePath, cache);
}
function _isStale(cachePath, cacheDuration) {
    return _mtime(cachePath).isBefore(moment().subtract(cacheDuration, 'seconds'));
}
function _mtime(f) {
    return moment(fs.statSync(f).mtime);
}
async function fetchCache(cachePath, cacheDuration, options) {
    let cachePresent = fs.existsSync(cachePath);
    if (cachePresent && !_isStale(cachePath, cacheDuration)) {
        return fs.readJSON(cachePath);
    }
    const cache = await options.cacheFn();
    // TODO: move this to a fork
    await _updateCache(cachePath, cache);
    return cache;
}
exports.fetchCache = fetchCache;
